% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gsmr.R
\name{bi_gsmr}
\alias{bi_gsmr}
\title{Bi-directional GSMR analysis}
\usage{
bi_gsmr(bzx, bzx_se, bzx_pval, bzy, bzy_se, bzy_pval, ldrho, snpid, heidi_outlier_flag=T, gwas_thresh=5e-8, heidi_outlier_thresh=0.01, nsnps_thresh=10)
}
\arguments{
\item{bzx}{vector, SNP effects on risk factor}

\item{bzx_se}{vector, standard errors of bzx}

\item{bzx_pval}{vector, p values for bzx}

\item{bzy}{vector, SNP effects on disease}

\item{bzy_se}{vector, standard errors of bzy}

\item{bzy_pval}{vector, p values for bzy}

\item{ldrho}{LD correlation matrix of the SNPs}

\item{snpid}{genetic instruments}

\item{heidi_outlier_flag}{flag for HEIDI-outlier analysis}

\item{gwas_thresh}{threshold p-value to select  instruments from GWAS for risk factor}

\item{heidi_outlier_thresh}{HEIDI-outlier threshold}

\item{nsnps_thresh}{the minimum number of instruments required for the GSMR analysis (we do not recommend users to set this number smaller than 10)}
}
\value{
Estimate of causative effect of risk factor on disease (forward_bxy), the corresponding standard error (forward_bxy_se), p-value (forward_bxy_pval) and SNP index (forward_index), and estimate of causative effect of disease on risk factor (reverse_bxy), the corresponding standard error (reverse_bxy_se), p-value (reverse_bxy_pval) and SNP index (reverse_index).
}
\description{
Bi-directional GSMR analysis is composed of a forward-GSMR analysis and a reverse-GSMR analysis that uses SNPs associated with the disease (e.g. at  < 5e-8) as the instruments to test for putative causal effect of the disease on the risk factor.
}
\examples{
data("gsmr")
gsmr_result = bi_gsmr(gsmr_data$bzx, gsmr_data$bzx_se, gsmr_data$bzx_pval, gsmr_data$bzy, gsmr_data$bzy_se, gsmr_data$bzy_pval, ldrho, gsmr_data$SNP, T, 5e-8, 0.01, 10) 

}
